<?php

namespace Drupal\coming_soon\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides route responses for the Example module.
 */
class ComingSoonController extends ControllerBase {

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Entity storage.
   *
   * @var Drupal\Core\Entity\EntityStorageInterface
   */
  protected $files;

  /**
   * Construct a formbuilder object.
   *
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   Form builder object.
   * @param Drupal\Core\Entity\EntityStorageInterface $entityStorage
   *   Entity Storage object.
   */
  public function __construct(FormBuilderInterface $form_builder, EntityStorageInterface $entityStorage) {
    $this->formBuilder = $form_builder;
    $this->files = $entityStorage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
     $container->get('form_builder'),
     $container->get('entity.manager')->getStorage('file')
     );
  }

  /**
   * Returns a simple page.
   *
   * @return array
   *   A simple renderable array.
   */
  public function index() {
    $form = $this->formBuilder->getForm('Drupal\coming_soon\Form\ComingSoonSubscribersForm');
    $config = $this->config('coming_soon.settings');
    $bg = $config->get('coming_soon_bg');
    $bg = !empty($bg) && (is_array($bg)) ? array_shift($bg) : NULL;
    if ($bg) {
      $bg = $this->files->load($bg);
    }
    $logo = theme_get_setting('logo.url');

    return [
      '#theme' => 'coming_soon_predefined_page',
      '#config' => $config,
      '#background' => $bg,
      '#form' => $form,
      '#logo' => $logo,
    ];
  }

}
